.. _tutorials-pulsards:

============================
Pulsar-ds
============================

The code for this example is located in the :mod:`examples.pulsards.manage`
module.

.. automodule:: examples.pulsards.manage
